import { AxiosError } from 'axios';
export declare type AppErrType = Error | AxiosError<any>;
export interface ErrorOptions {
    shouldReport?: boolean;
    debugMessage?: string;
}
export interface ErrorConfig {
    initSentry: () => any;
    getUser?: () => Promise<{
        email?: string;
        name?: string;
        [key: string]: any;
    }>;
    extraSentryData?: any;
}
export declare function setup(errorConfig: ErrorConfig): void;
export declare class AppError extends Error {
    userMsg: string;
    message: string;
    err: AppErrType;
    originalErrMsg: string;
    debugMsg: string;
    isAxiosErr: boolean;
    customErrCode: string | null;
    messageBag: null | {
        [key: string]: any;
    };
    contexts: {
        [key: string]: any;
    } | undefined;
    statusCode?: number;
    isConnectFailed?: boolean;
    constructor(err: AppErrType | unknown | string, userMessage?: string, { debugMessage, shouldReport }?: ErrorOptions);
    handleErr: (userMessage: string, shouldReport: boolean) => void;
    isNetworkError: (error: AppErrType) => boolean;
    printLog: (error: AppErrType) => void;
}
export declare function reportToSentry(err: AppErrType, debugMsg?: string): Promise<void>;
